@@ -7,7 +7,9 @@ class AllowAuthenticated:
     """Allows performing action only for logged in users."""
 
     def has_node_permission(
-        self, info: ResolveInfo, obj_id: str,  # noqa: WPS110
+        self,
+        info: ResolveInfo,  # noqa: WPS110
+        obj_id: str,  # noqa: WPS110
     ) -> bool:
         """Check has node permission."""
         return info.context.user.is_authenticated  # type:ignore
@@ -22,7 +24,8 @@ class AllowAuthenticated:
         return info.context.user.is_authenticated  # type:ignore
 
     def has_filter_permission(
-        self, info: ResolveInfo,  # noqa: WPS110
+        self,
+        info: ResolveInfo,  # noqa: WPS110
     ) -> bool:
         """Check has filter permission."""
         return info.context.user.is_authenticated  # type:ignore
